###' Number of people infectious in regions at time t
###'
###' Return the number of infectious individuals in regions at given times.
###'
###' @param t the time
###' @param window length of time window
###' @param cases case data
###' @param R region codes
###' @return number of infections at time t
###' @export
mCount <- function(t,window,cases,R){
  times = caseTimes(cases)
  locations = caseRegions(cases)
  casesInTime = (t-window < times) & (times < t)
  return(as.vector(table(factor(locations[casesInTime],levels=R))))
}


###' Number of people infected at all time points
###'
###' Return the number of infectious cases in regions at all case time points
###'
###' @param window length of time window
###' @param cases case data
###' @param R region codes
###' @return number of infections at times of the cases
###' @export
mCounts <- function(window,cases,R){
  mc = laply(caseTimes(cases,numeric=TRUE), function(x) {mCount(x, window, cases, R) })
  colnames(mc)=R
  return(mc)
}
