
###' contruct a table of values, stderrs etc
###'
###' given a fitted model, return a coefficient matrix
###' @param fit fitted plim model
###' @param scale multiplier for the hessian matrix because optim minimises
###' @export
plimtable <- function(fit,scale=-1){
  est = fit$par
  se <- sqrt(diag(solve(scale*fit$hessian)))
  tval <- est/se
  coefficients <- cbind(est, se, tval, 2 * pnorm(q=abs(est),mean=0,sd=se, lower.tail = FALSE))
  dimnames(coefficients) <- list(names(fit$par), 
        c("Estimate", "Std. Error", "Z value", "Pr(>|Z|)"))
  class(coefficients) <- "plimtable"
  attr(coefficients,'value')=fit$value
  attr(coefficients,'convergence')=fit$convergence
  return(coefficients)
}

###' print a plim table
###'
###' print method for plim tables
###' @param x a plimtable
###' @param ... other args, unused for now
###' @export
print.plimtable <- function(x,...){
  ll = attr(x,'value')
  con = attr(x,'convergence')
  attr(x,'value')=NULL
  attr(x,'convergence')=NULL
  print.default(unclass(x))
  cat("Log-likelihood: ",ll,'\n')
  if(con!=0){
    warning("Model convergence code == ",con)
  }
}

    
