###' Generate region-time case data
###'
###' Convert a data frame to region-time data
###'
###' @param cases data frame of cases
###' @param regionCol which column is the region
###' @param timeCol which column is the time
###'
###' @return the same data frame but with region/time column attributes
###' @export
stCases <- function(cases,regionCol,timeCol){
  attr(cases,"regionCol")=regionCol
  attr(cases,"timeCol")=timeCol
  return(cases)
}

###' Get the case times
###'
###' returns the case times for region-time data
###'
###' @param cases a region-time data frame
###' @param numeric convert times to numeric
###'
###' @return vector of case times
###' @export
caseTimes <- function(cases, numeric=FALSE){
  ct = cases[[attr(cases,"timeCol")]]
  if(numeric){
    return(as.numeric(ct))
  }else{
    return(ct)
  }
}

###' Get the case regions
###'
###' returns the case regions for region-time data
###'
###' @param cases a region-time data frame
###' @param character coerce to character
###'
###' @return vector of case regions
###' @export
caseRegions <- function(cases,character=TRUE){
  rr = cases[[attr(cases,"regionCol")]]
  if(character){
    rr = as.character(rr)
  }
  return(rr)
}
