###' Transmission model likelihood Using Slow R Code
###'
###' compute the likelihood for the given parameters
###'
###' @param params initial parameters
###' @param cases region-time case data
###' @param pop population vector
###' @param Z covariate generator
###' @param W interaction term generator
###' @param mC counts of cases at times in regions
###' @return the log-likelihood given the parameters
###' @export
###' @examples
###' m = makeData(seed=123)
###' mc = mCounts(m$window, m$cases, m$R) 
###' transModelLik(c(alpha=0,alpha=0,beta=0,beta=0),m$cases,pop=m$pop,Z=m$Z,m$W,mc)
transModelLik <- function(params, cases, pop, Z, W, mC){
###
  ll = 0
  ct = caseTimes(cases)
  cr = match(caseRegions(cases),attr(W,"regions"))
  alpha = params[names(params)=="alpha"]
  beta = params[names(params)=="beta"]
  gamma = params[names(params)=="gamma"]

  for(r in 1:nrow(cases)){
    k = cr[r] ## which region
    t = ct[r]

    C = W(t, gamma)

    if(length(alpha)>0){
      A = exp(Z(t) %*% alpha)
      B = exp(Z(t) %*% beta)
      lambdaDash = outer(as.vector(A),as.vector(B)) * C
    }else{
      lambdaDash = C
    }

    ## get number of cases in the history for each region
    mt = mC[r,]
    ## skip if there's no contributing cases in the history:
    if(!all(mt==0)){
      top = pop[k] * sum(mt * lambdaDash[,k])
      b1 = colSums(mt * lambdaDash)
      bottom = sum(pop * b1)
      p = top/bottom
      #cat(sprintf("Case:%d Top: %f Bottom: %f logp: %f\n",r,top,bottom,log(top/bottom)))
      if(!is.numeric(p)){
        warning("Something went non-numeric in likelihood calculation.")
        browser()
      }
      #print(p)
      ll = ll + log(p)
    }
  }
  return(ll)
}
